@@ -410,7 +410,9 @@ where
                             // Sign does not matter for NaN
                             *e = Expr::Ident(Ident::new(
                                 js_word!("NaN"),
-                                bin.span.with_ctxt(SyntaxContext::empty()),
+                                bin.span.with_ctxt(
+                                    SyntaxContext::empty().apply_mark(self.marks.unresolved_mark),
+                                ),
                             ));
                         }
                         (FpCategory::Normal, FpCategory::Zero) => {
