@@ -1,7 +1,7 @@
 use swc_common::{util::take::Take, FileName};
 use swc_ecma_ast::*;
 use swc_ecma_parser::parse_file_as_expr;
-use swc_ecma_transforms::fixer;
+use swc_ecma_transforms_base::fixer::fixer;
 use swc_ecma_visit::{noop_visit_mut_type, FoldWith, VisitMut, VisitMutWith};
 use tracing::{info, warn};
 
